@@ -1,7 +1,6 @@
 import math
 
 import pandas as pd
-import seaborn as sns
 from matplotlib import pyplot as plt
 
 from chester.zero_break.problem_specification import DataInfo
@@ -57,11 +56,13 @@ class CategoricalStats:
             ax1.set_title(f"{col}")
             return None
         else:
-            dim = max(math.ceil(math.sqrt(len(top_n))), 2)
-            fig, ax = plt.subplots(dim, dim, figsize=(18, 15))
+            dim = max(math.floor(math.sqrt(len(top_n))), 2)
+            fig, ax = plt.subplots(dim, dim, figsize=(18, 3 + 3 * dim))
             fig.tight_layout()
             fig.suptitle("Top 5 Value Counts and Percentages for Each Feature")
             for i, col in enumerate(top_n):
+                if i >= dim * dim:
+                    break
                 count_data = pd.DataFrame(self.data[col].value_counts()[0:5]).reset_index(drop=False)
                 total_count = self.data[col].count()
                 percent_data = count_data.copy()
@@ -73,12 +74,11 @@ class CategoricalStats:
                 ax1_i = ax_i
                 ax1_i.bar(count_data.iloc[:, 0], count_data.iloc[:, 1].to_list(), color='gray')
                 ax2_i = ax1_i.twinx()
-                ax2_i.plot(percent_data.iloc[:, 0], percent_data.iloc[:, 1].to_list(), color='red', marker='o')
+                ax2_i.plot(percent_data.iloc[:, 0], percent_data.iloc[:, 1].to_list(), marker='o', color='red')
                 ax1_i.set_ylabel('Counts', color='gray')
                 ax2_i.set_ylabel('Percentages', color='red')
                 ax1_i.set_xlabel(None)
                 ax1_i.set_title(plot_title)
-            # plt.tight_layout()
             plt.show()
             plt.close()
 
