@@ -76,7 +76,7 @@ class ImagePostModelAnalysis:
             eval_predictions = vmap_labels(self.eval_predictions)
 
         if torch.cuda.is_available():
-            cm = confusion_matrix(eval_labels, eval_labels.cpu().numpy())
+            cm = confusion_matrix(eval_labels, eval_predictions.cpu().numpy())
         else:
             cm = confusion_matrix(eval_labels, eval_predictions)
 
