@@ -16,6 +16,7 @@ class ImagesData:
         self.validation_prop = validation_prop
         self.image_shape = image_shape
         self.label_dict = label_dict
+        self.validate()
         self.problem_type = self.get_problem_type()
         # reshape
         # Convert to ndarray and reshape
@@ -32,6 +33,11 @@ class ImagesData:
         else:
             print("Grayscale image")
 
+    def validate(self):
+        if self.labels is None:
+            pass
+        assert (len(self.images) == len(self.labels), "# of Images must be == # of labels")
+
     def image_to_show(self):
         images = self.images.reshape((-1,) + self.image_shape)
         if self.is_colored:
